Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(547)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutBlockFlow.h

Issue 2505943003: Rename positionNewFloats() to placeNewFloats(). (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/LayoutBlockFlow.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutBlockFlow.h b/third_party/WebKit/Source/core/layout/LayoutBlockFlow.h
index 2eb3e8829d4aaeae6486d765fb33072a6747fb32..e62f94232e9b9dedc56b224efe1b73b6799bbab9 100644
--- a/third_party/WebKit/Source/core/layout/LayoutBlockFlow.h
+++ b/third_party/WebKit/Source/core/layout/LayoutBlockFlow.h
@@ -348,19 +348,24 @@ class CORE_EXPORT LayoutBlockFlow : public LayoutBlock {
FloatingObject* insertFloatingObject(LayoutBox&);
- // Position all floats that have not yet been positioned.
+ // Position and lay out all floats that have not yet been positioned.
//
- // |logicalTop| is the minimum logical top for the floats. The final logical
- // top of the floats will also be affected by clearance and space available
- // after having positioned earlier floats.
+ // This will mark them as "placed", which means that they have found their
+ // final location in this layout pass.
//
- // Returns true if and only if it has positioned any floats.
- bool positionNewFloats(LayoutUnit logicalTop, LineWidth* = nullptr);
+ // |logicalTopMarginEdge| is the minimum logical top for the floats. The
+ // final logical top of the floats will also be affected by clearance and
+ // space available after having positioned earlier floats.
+ //
+ // Returns true if and only if it has placed any floats.
+ bool placeNewFloats(LayoutUnit logicalTopMarginEdge, LineWidth* = nullptr);
// Position and lay out the float, if it needs layout.
- // |logicalTop| is the minimum logical top offset for the float (margin edge).
- // The value returned is the minimum logical top offset for subsequent floats.
- LayoutUnit positionAndLayoutFloat(FloatingObject&, LayoutUnit logicalTop);
+ // |logicalTopMarginEdge| is the minimum logical top offset for the float.
+ // The value returned is the minimum logical top offset for subsequent
+ // floats.
+ LayoutUnit positionAndLayoutFloat(FloatingObject&,
+ LayoutUnit logicalTopMarginEdge);
LayoutUnit nextFloatLogicalBottomBelow(LayoutUnit) const;
LayoutUnit nextFloatLogicalBottomBelowForBlock(LayoutUnit) const;
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/layout/LayoutBlockFlow.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698